// interface to the aircraft
// OpenRadioControl
// (C) BritishIdeas.com 2011 andy@britishideas.com
// This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License
// http://creativecommons.org/licenses/by-nc-sa/3.0/
// THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
// OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
// BRITISHIDEAS SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
// CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
// $Id: aircraft.h 400 2011-10-21 23:10:51Z andy $

#ifndef _AIRCRAFTH_
#define _AIRCRAFTH_

#include "config.h"

// groups directions into positive and negative
typedef enum
{
    LeftDown,
    RightUp
} direction;

// initializes the module
// starts communication with the aircraft via the transmitter
extern void Aircraft_Init
  (
  int NumberofChannels                                     // number of channels
  );

// sets the stick value for a channel
extern void Aircraft_SetStick
    (
    int Channel,                                           // channel to set (1 - NumChannels)
    int Value                                              // percentage -100 to 100 (0 = center)
    );

// sets the trim value for a channel
extern void Aircraft_SetTrim
    (
    int Channel,                                           // channel to set (1 - NumChannels)
    int Value                                              // percentage -100 to 100 (0 = center)
    );

// gets the trim value for a channel
extern int Aircraft_GetTrim
  (
  int Channel                                              // channel to set (1 - NumChannels)
  );

// gets the stick value for a channel
extern int Aircraft_GetStick
  (
  int Channel                                              // channel to get (1 - NumChannels)
  );

// sets the travel volume for a channel
void Aircraft_SetTravelVolume
    (
    int Channel,                                           // channel to set (1 - NumChannels)
    direction Direction,                                   // direction of channel volume
    int Value                                              // percentage 10 to 120
    );

// increases the trim on a channel
// equivalent to moving the trim slider one click on a regular transmitter
// returns new trim position
extern int Aircraft_AddTrim
    (
    int Channel                                            // channel to set (1 - NumChannels)
    );

// increases the trim on a channel
// returns new trim position
extern int Aircraft_AddTrimByAmount
    (
    int Channel,                                           // channel to set (1 - NumChannels)
    int Amount                                             // amount to increase trim by in percentage
    );

// decreases the trim on a channel
// equivalent to moving the trim slider one click on a regular transmitter
// returns new trim position
extern int Aircraft_SubtractTrim
    (
    int Channel                                            // channel to set (1 - NumChannels)
    );

// decreases the trim on a channel
// returns new trim position
extern int Aircraft_SubtractTrimByAmount
    (
    int Channel,                                           // channel to set (1 - NumChannels)
    int Amount                                             // amount to decreate trim by in percentage
    );

// sets the servo direction on a channel
extern void Aircraft_SetChannelDirection
    (
    int Channel,                                           // channel to configure (1 - NumChannels)
    int Reverse                                            // zero = not reversed, non-zero = reversed
    );

#endif // _AIRCRAFTH_
