// configuration module
// stores configuration data in non-volatile memory
// OpenRadioControl
// (C) BritishIdeas.com 2011 andy@britishideas.com
// This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License
// http://creativecommons.org/licenses/by-nc-sa/3.0/
// THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
// OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
// BRITISHIDEAS SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
// CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
// $Id: configuration.h 399 2011-10-20 21:51:15Z andy $

#ifndef _CONFIGURATIONH_
#define _CONFIGURATIONH_

#include <stdint.h>

// maximum number of supported aircraft
#define MAXAIRCRAFT 8
// maximum number of supported channels
#define MAXCHANNELS 8
// maximum length of an aircraft name including null terminator
#define MAXAIRCRAFTNAME 32

// initializes the configuration module
extern void Configuration_Init
    (
    void
    );    

// selects an aircraft to use
extern void Configuration_SetCurrentAircraft
    (
    uint32_t AircraftNumber                                // number of the aircraft (1 - MAXAIRCRAFT)
    );

// gets the currently selected aircraft
extern uint32_t Configuration_GetCurrentAircraft
    (
    void
    );

// stores the current throttle value
extern void Configuration_SetCurrentThrottle
  (
  int32_t ThrottleValue                                    // throttle value (-100 to 100)
  );

// gets the last known throttle value
extern uint32_t Configuration_GetLastKnownThrottle
  (
  void
  );

// sets the number of channels for an aircraft
extern void Configuration_SetAircraftNumChannels
    (
    uint32_t AircraftNumber,                               // aircraft number (1 - NUMAIRCRAFT)
    uint32_t NumChannels                                   // number of channels
    );

// sets the name of an aircraft
extern void Configuration_SetAircraftName
  (
  uint32_t AircraftNumber,                                 // aircraft number (1 - NUMAIRCRAFT)
  char *Name                                               // name of the aircraft (max 31 characters)
  );

// sets the direction of the channel (reversed or not reversed)
extern void Configuration_SetChannelDirection
  (
  uint32_t Aircraft,                                       // number of the aircraft (1 - NUMAIRCRAFT)
  uint32_t Channel,                                        // number of the channel (1 - NUMCHANNELS)
  int Reverse                                              // zero = not reversed, non-zero = reversed
  );

// sets the trim of the channel
extern void Configuration_SetChannelTrim
  (
  uint32_t Aircraft,                                       // number of the aircraft (1 - MAXAIRCRAFT)
  uint32_t Channel,                                        // number of the channel (1 - MAXCHANNELS)
  int32_t Trim                                             // -100 to +100
  );

// sets the left/down travel volume of the channel
extern void Configuration_SetChannelLeftDownTravelVolume
  (
  uint32_t Aircraft,                                       // number of the aircraft (1 - MAXAIRCRAFT)
  uint32_t Channel,                                        // number of the channel (1 - MAXCHANNELS)
  uint32_t TravelVolume                                    // +10 to +120
  );

// sets the right/up travel volume of the channel
extern void Configuration_SetChannelRightUpTravelVolume
  (
  uint32_t Aircraft,                                       // number of the aircraft (1 - MAXAIRCRAFT)
  uint32_t Channel,                                        // number of the channel (1 - MAXCHANNELS)
  uint32_t TravelVolume                                    // +10 to +120
  );

// sets the channel assignments
extern void Configuration_SetChannelAssignments
  (
  uint32_t Aircraft,                                       // number of the aircraft (1 - MAXAIRCRAFT)
  uint32_t ThrottleChannel,                                // channel number for throttle (1 - MAXCHANNELS)
  uint32_t AileronsChannel,                                // channel number for ailerons (1 - MAXCHANNELS)
  uint32_t RudderChannel,                                  // channel number for rudder (1 - MAXCHANNELS)
  uint32_t ElevatorsChannel                                // channel number for elevators (1 - MAXCHANNELS)
  );

// gets the number of channels for an aircraft
extern uint32_t Configuration_GetAircraftNumChannels
    (
    uint32_t AircraftNumber                                // aircraft number (1 - NUMAIRCRAFT)
    );

// gets the name of an aircraft
extern void Configuration_GetAircraftName
  (
  uint32_t AircraftNumber,                                 // aircraft number (1 - NUMAIRCRAFT)
  char *Name                                               // location to store name of the aircraft (max 31 characters)
  );

// gets the direction of the channel (reversed or not reversed)
// returns zero if not reversed, returns 1 if reversed
extern int Configuration_GetChannelDirection
  (
  uint32_t Aircraft,                                       // number of the aircraft (1 - MAXAIRCRAFT)
  uint32_t Channel                                         // number of the channel (1 - MAXCHANNELS)
  );

// gets the trim of the channel
// returns the trim -100 to +100
extern int32_t Configuration_GetChannelTrim
  (
  uint32_t Aircraft,                                       // number of the aircraft (1 - MAXAIRCRAFT)
  uint32_t Channel                                         // number of the channel (1 - MAXCHANNELS)
  );

// gets the left/down travel volume of the channel
extern uint32_t Configuration_GetChannelLeftDownTravelVolume
  (
  uint32_t Aircraft,                                       // number of the aircraft (1 - MAXAIRCRAFT)
  uint32_t Channel                                         // number of the channel (1 - MAXCHANNELS)
  );

// gets the right/up travel volume of the channel
extern uint32_t Configuration_GetChannelRightUpTravelVolume
  (
  uint32_t Aircraft,                                       // number of the aircraft (1 - MAXAIRCRAFT)
  uint32_t Channel                                         // number of the channel (1 - MAXCHANNELS)
  );

// sets the channel assignments
extern void Configuration_GetChannelAssignments
  (
  uint32_t Aircraft,                                       // number of the aircraft (1 - MAXAIRCRAFT)
  uint32_t *ThrottleChannel,                               // filled with channel number for throttle
  uint32_t *AileronsChannel,                               // filled with channel number for ailerons
  uint32_t *RudderChannel,                                 // filled with channel number for rudder
  uint32_t *ElevatorsChannel                               // filled with channel number for elevators
  );

#endif // _CONFIGURATIONH_
